@@ -1,10 +1,9 @@
 require File.dirname(__FILE__) + '/if'
 
 module Liquid
-
   # Unless is a conditional just like 'if' but works on the inverse logic.
   #
-  #   {% unless x < 0 %} x is greater than zero {% end %}
+  #   {% unless x < 0 %} x is greater than zero {% endunless %}
   #
   class Unless < If
     def render(context)
@@ -23,11 +22,10 @@ module Liquid
           end
         end
 
-        ''
+        ''.freeze
       end
     end
   end
 
-
-  Template.register_tag('unless', Unless)
+  Template.register_tag('unless'.freeze, Unless)
 end
